from distutils.core import setup
setup(
  name = 'meiniu',
  packages = ['meiniu'], # this must be the same as the name above
  version = '0.1',
  description = 'simple menu generator',
  author = 'p1ngu1n0',
  author_email = 'p1ngu1n0@protonmail.com',
  url = 'https://github.com/p1ngu1n0/meiniu', # use the URL to the github repo
  download_url = 'https://github.com/p1ngu1n0/meiniu/tarball/0.1',
  keywords = ['menu', 'generator', 'py menu'],
  classifiers = [],
)